import java.awt.Color;

/**
 * An image filter to include salt and pepper noise in an image.
 *
 * @author Michael Kolling and David J Barnes and Monica
 * @version 1.0
 */
public class SaltPepperFilter extends Filter
{
   final static int nSalt = 5;    // Percentage of salt
   final static int nPepper = 5;  // Percentage of pepper

     /**
         * Constructor for objects of class SaltPepperFilter.
     * @param name The name of the filter.
         */
    public SaltPepperFilter(String name)
    {
        super(name);
    }

    /**
     * Apply this filter to an image.
     *
     * @param  image  The image to be changed by this filter.
     */
    public void apply(OFImage image)
    {
        int height = image.getHeight();
        int width = image.getWidth();
        
        int salt = height * width * nSalt / 100;    // Amount of salt
        int pepper = height * width * nSalt / 100;  // Amount of pepper
        
        for( int i = 0; i < salt; i++ )
        {
            int x = (int) (Math.random() * width); 
            int y = (int) (Math.random() * height);
            
            image.setPixel( x, y, new Color( 255, 255, 255 ) );
        }
        
        for( int i = 0; i < pepper; i++ )
        {
            int x = (int) (Math.random() * width); 
            int y = (int) (Math.random() * height);
            
            image.setPixel( x, y, new Color( 0, 0, 0 ) );
        }
    }
}
